@@ -23,8 +23,12 @@ class Astrometry(object):
 
     def __init__(self, data_choice, star_id, intermediate_data_directory, fitter=None, data=None,
                  central_epoch_ra=0, central_epoch_dec=0, format='jd', fit_degree=1,
-                 use_parallax=False, central_ra=None, central_dec=None, normed=False):
+                 use_parallax=False, central_ra=None, central_dec=None, **kwargs):
 
+        if 'normed' in kwargs:
+            warnings.warn('normed keyword argument is Depreciated and will be removed in the next minor version ' 
+                          'of htof. Please delete normed=False wherever it is used. Note that neither '
+                          'normed=True nor False have any affect as of 0.3.5.', DeprecationWarning)
         if data is None:
             DataParser = self.parsers[data_choice.lower()]
             data = DataParser()
@@ -51,8 +55,7 @@ class Astrometry(object):
                                        central_epoch_ra=Time(central_epoch_ra, format=format).value,
                                        fit_degree=fit_degree,
                                        use_parallax=use_parallax,
-                                       parallactic_pertubations=parallactic_pertubations,
-                                       normed=normed)
+                                       parallactic_pertubations=parallactic_pertubations)
         self.data = data
         self.fitter = fitter
 
